@@ -5,7 +5,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0202';
+our $VERSION = '0.0203';
 
 use Moo;
 use strictures 2;
@@ -155,7 +155,7 @@ MIDI::RtController - Control your MIDI controller
 
 =head1 VERSION
 
-version 0.0202
+version 0.0203
 
 =head1 SYNOPSIS
 
@@ -178,7 +178,7 @@ version 0.0202
     return 0;
   }
 
-  $rtc->add_filter($_ => \&pedal_tone) for qw(note_on note_off);
+  $rtc->add_filter($_ => \&filter_tone) for qw(note_on note_off);
 
   # add other stuff to the $rtc->loop...
 
@@ -256,9 +256,14 @@ Run the asynchronous B<loop>!
 Add a filter, defined by the CODE reference B<action>, for an
 B<event_type> like C<note_on> or C<note_off>.
 
+=head1 THANK YOU
+
+This code would not exist without the help of CPAN's JBARRETT (John
+Barrett AKA fuzzix).
+
 =head1 SEE ALSO
 
-The F<eg/*.pl> program(s)
+The F<eg/*.pl> example program(s)
 
 L<Future::AsyncAwait>
 
